<?php

namespace Teknisa\MAN\Services;

use Doctrine\DBAL\Connection;
use Teknisa\MAN\Utilities;
use Doctrine\ORM\EntityManager;


class ManutencaoCampanhaFidelidade {

    protected $conn;

    public function __construct(Connection $conn) {
        $this->conn = $conn;
    }


    public function findCampFidelidade($row){
        
        $params = array(
            ':NRORG'        => $row['NRORG'],
            ':CDFILIAL'     => $row['CDFILIAL'],
            ':DATAINI'      => $row['DATAINI'],
            ':CDCAMPANHA'   => $row['CDCAMPANHA'],
            ':CDCLIENTE'    => $row['CDCLIENTE'],
            ':CDCONSUMIDOR' => $row['CDCONSUMIDOR']
        );
        
        $data = $this->conn->fetchAll(self::MANUTENCAO_CAMPANHA_FIDELIDADE, $params);
        
        return $data;
    }

    public function findCampByFilial($row){
        $params = array(
            ':NRORG'        => $row[0]['value'],
            ':CDFILIAL'     => $row[1]['value']
        );
        
        $data = $this->conn->fetchAll(self::GET_CAMP_BY_FILIAL, $params);
        return $data;
    }
    

    public function findVoucher($row){
        $params = array(
            ':NRORG'        => $row[0]['value'],
            ':CDCAMPANHA'   => $row[1]['value'],
            ':CDCLIENTE'    => $row[2]['value'],
            ':CDCONSUMIDOR' => $row[3]['value']
        );
        $data = $this->conn->fetchAll(self::MANUTENCAO_CAMPANHA_FIDELIDADE_VOUCHER, $params);
        return $data;
    }
    
    public function verifyExistVoucher($row){
        $params = array(
            ':NRORG'        => $row[0]['value'],
            ':CDCAMPANHA'   => $row[1]['value'],
            ':CDCLIENTE'    => $row[2]['value'],
            ':CDCONSUMIDOR' => $row[3]['value'],
            ':DATAHOJE'     => $row[4]['value']
        );
        
        $std = $this->conn->prepare(self::MANUTENCAO_CAMPANHA_FIDELIDADE_VALID_VOUCHER);
        $std->execute($params);
        $data = $std->fetch();
        return $data;
    }
    
    public function findSaldoAtual($row){
        $params = array(
            ':NRORG'        => $row[0]['value'],
            ':CDCAMPANHA'   => $row[1]['value'],
            ':CDCLIENTE'    => $row[2]['value'],
            ':CDCONSUMIDOR' => $row[3]['value']
        );
        
        $data = $this->conn->fetchAll(self::MANUTENCAO_CAMPANHA_FIDELIDADE_SALDO, $params);
        return $data;
    }
    
    public function findOperador($cdoperador){
        $params = array(
            ':CDOPERADOR'   => $cdoperador
        );
        
        $std = $this->conn->prepare(self::MANUTENCAO_CAMPANHA_FIDELIDADE_OPERADOR);
        $std->execute($params);
        $operador = $std->fetch();
        return $operador;
    }
    
    public function saveCampFidelidade($row){
        $params = array(
            ':CDFILIAL'         => $row['CDFILIAL'],
            ':CDCAMPANHA'       => $row['CDCAMPANHA'],
            ':CDCLIENTE'        => $row['CDCLIENTE'],
            ':NRORG'            => $row['NRORG'],
            ':CDCONSUMIDOR'     => $row['CDCONSUMIDOR'],
            ':NRSEQMOVCONS'     => $row['NRSEQMOVCONS'],
            ':IDTPMOVCONS'      => $row['IDTPMOVCONS'],
            ':VRMOVPONTOCONS'   => $row['VRMOVPONTOCONS'],
            ':DTMOVPONTOCONS'   => $row['DTMOVPONTOCONS'],
            ':DTINCLUSAO'       => $row['DTINCLUSAO'],
            ':DTULTATU'         => $row['DTULTATU'],
            ':NRORGINCLUSAO'    => $row['NRORG'],
            ':CDOPERINCLUSAO'   => $row['CDOPERINCLUSAO'],
            ':NRORGULTATU'      => $row['NRORG'],
            ':CDOPERULTATU'     => $row['CDOPERINCLUSAO'],
            ':DSOBSMOVPTOCONS'  => $row['DSOBSMOVPTOCONS'],
            ':DTVALIDAPONTO'    => $row['DTVALIDAPONTO'],
            ':VRSALDOCONS'      => $row['VRSALDOCONS']
              
        );
        
        $data = $this->conn->executeQuery(self::MANUTENCAO_CAMPANHA_FIDELIDADE_INSERT, $params);
        return $data;
    }
    
    public function updateCampFidelidade($row) {
        $params = array(
            ':DSOBSMOVPTOCONS'  => $row['DSOBSMOVPTOCONS'],
            ':CDCAMPANHA'       => $row['CDCAMPANHA'],
            ':CDCLIENTE'        => $row['CDCLIENTE'],
            ':CDCONSUMIDOR'     => $row['CDCONSUMIDOR'],
            ':NRORG'            => $row['NRORG']
        );
        
        $data = $this->conn->executeQuery(self::MANUTENCAO_CAMPANHA_FIDELIDADE_UPDATE, $params);
        return $data;
    }
    
    public function getCodManut($row) {
        
        $params = array (
            'NRORG' => $row[0]['value']
        );
        
        $data = $this->conn->fetchAll(self::GET_COD_MANUT, $params);
        return $data;
    }
    
  const MANUTENCAO_CAMPANHA_FIDELIDADE_VOUCHER = "
      SELECT NRSEQVOUCHER, DTGERVOUCHER, DTVALVOUCHER, VRPTOVOUCHER,
    IDUTIVOUCHER, DTUTIVOUCHER
    FROM VOUCHERVND
    WHERE CDCAMPANHA = :CDCAMPANHA
     AND CDCLIENTE = :CDCLIENTE
     AND CDCONSUMIDOR = :CDCONSUMIDOR
     AND NRORG = :NRORG
    ORDER BY NRSEQVOUCHER
  ";
  
  const GET_CAMP_BY_FILIAL = "
        SELECT FCAMP.CDCAMPANHA, CAMP.DSCAMPANHA FROM FILICAMPANHA FCAMP
        JOIN CAMPANHA CAMP
            ON CAMP.CDCAMPANHA = FCAMP.CDCAMPANHA 
        WHERE FCAMP.CDFILIAL = :CDFILIAL
            AND FCAMP.NRORG = :NRORG
        ORDER BY FCAMP.CDCAMPANHA
  ";
    
  const MANUTENCAO_CAMPANHA_FIDELIDADE_INSERT = "
        INSERT INTO MOVPONTOCONS
            (CDFILIAL, CDCAMPANHA, CDCLIENTE, NRORG, CDCONSUMIDOR, NRSEQMOVCONS, IDTPMOVCONS, VRMOVPONTOCONS, DTMOVPONTOCONS, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, DSOBSMOVPTOCONS, DTVALIDAPONTO, VRSALDOCONS)
        VALUES
            (:CDFILIAL, :CDCAMPANHA, :CDCLIENTE, :NRORG, :CDCONSUMIDOR, :NRSEQMOVCONS, :IDTPMOVCONS, :VRMOVPONTOCONS, :DTMOVPONTOCONS, :DTINCLUSAO, :DTULTATU, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU, :DSOBSMOVPTOCONS, :DTVALIDAPONTO, :VRSALDOCONS)
  ";
    
  const MANUTENCAO_CAMPANHA_FIDELIDADE_UPDATE = "
        UPDATE MOVPONTOCONS
        SET DSOBSMOVPTOCONS = :DSOBSMOVPTOCONS
        WHERE CDCAMPANHA = :CDCAMPANHA
            AND CDCLIENTE = :CDCLIENTE
            AND CDCONSUMIDOR = :CDCONSUMIDOR
            AND NRORG = :NRORG
  ";
  
    
  const MANUTENCAO_CAMPANHA_FIDELIDADE_OPERADOR = "
    SELECT CDOPERADOR CDOPERINCLUSAO, NMOPERADOR 
      FROM OPERADOR 
    WHERE CDOPERADOR = :CDOPERADOR
  ";
  
  const MANUTENCAO_CAMPANHA_FIDELIDADE_SALDO = "
    SELECT VRSALDOCONS
    FROM SALDOCONSCAMP
    WHERE
        CDCAMPANHA = :CDCAMPANHA
        AND CDCLIENTE = :CDCLIENTE
        AND CDCONSUMIDOR = :CDCONSUMIDOR
        AND NRORG = :NRORG
  ";
  
   const MANUTENCAO_CAMPANHA_FIDELIDADE_VALID_VOUCHER = "
      SELECT COUNT(*) AS QTVOUCHER
    FROM VOUCHERVND
    WHERE CDCAMPANHA = :CDCAMPANHA
    AND CDCLIENTE = :CDCLIENTE
    AND CDCONSUMIDOR = :CDCONSUMIDOR
    AND DTVALVOUCHER >= :DATAHOJE
    AND IDUTIVOUCHER = 'N'
    AND NRORG = :NRORG
  ";
  
   const MANUTENCAO_CAMPANHA_FIDELIDADE = "
    SELECT M.CDCAMPANHA, M.CDCLIENTE, M.CDCONSUMIDOR, M.IDTPMOVCONS,
    M.DTMOVPONTOCONS, M.VRMOVPONTOCONS, M.CDFILIAL, M.CDCAIXA, M.NRSEQVENDA,
    M.NRSEQMOVCONS, M.DSOBSMOVPTOCONS, M.DTINCLUSAO,
    M.CDOPERINCLUSAO, O.NMOPERADOR, M.DTVALIDAPONTO, M.VRSALDOCONS, M.NRORG, C.NMCONSUMIDOR,
    F.NMFILIAL, CMP.DSCAMPANHA, CL.NMRAZSOCCLIE
    FROM MOVPONTOCONS M
    LEFT JOIN OPERADOR O
     ON M.CDOPERINCLUSAO = O.CDOPERADOR
     AND M.NRORG = O.NRORG
        LEFT JOIN CONSUMIDOR C
        ON C.CDCONSUMIDOR = :CDCONSUMIDOR
            LEFT JOIN FILIAL F
            ON F.CDFILIAL = :CDFILIAL
                LEFT JOIN CAMPANHA CMP
                ON CMP.CDCAMPANHA = :CDCAMPANHA
                    LEFT JOIN CLIENTE CL
                    ON CL.CDCLIENTE = :CDCLIENTE
    WHERE M.CDCAMPANHA = :CDCAMPANHA
     AND M.CDFILIAL = :CDFILIAL
     AND M.CDCLIENTE = :CDCLIENTE
     AND M.CDCONSUMIDOR = :CDCONSUMIDOR
     AND M.NRORG =:NRORG
     AND TRUNC(M.DTMOVPONTOCONS) >= :DATAINI
     AND ((M.DSOBSMOVPTOCONS NOT LIKE 'Cancela%') OR (M.DSOBSMOVPTOCONS IS NULL))
    ORDER BY M.NRSEQMOVCONS
  ";
  
  const GET_COD_MANUT = "
   SELECT LPAD(MAX(NRSEQMOVCONS)+1, 10, '0') AS NRSEQMOVCONS FROM MOVPONTOCONS WHERE NRORG = :NRORG
  ";
}